supa_addons
library
Classes
AddPartitionSpecUpdate
AddSchemaUpdate
AddSortOrderUpdate
AdminUserAttributes
AMREntry
An authentication method reference (AMR) entry.
AnalyticsBucket
A bucket backed by the Apache Iceberg table format, used for structured
analytical data storage.
ApiVersions
AssertCreate
AssertCurrentSchemaId
AssertDefaultSortOrderId
AssertDefaultSpecId
AssertLastAssignedFieldId
AssertLastAssignedPartitionId
AssertReferenceSnapshotId
AssertTableUuid
AssignUuidUpdate
AuthClientOptions
AuthMFAAdminDeleteFactorResponse
AuthMFAAdminListFactorsResponse
AuthMFAChallengeResponse
AuthMFAEnrollResponse
AuthMFAGetAuthenticatorAssuranceLevelResponse
AuthMFAListFactorsResponse
AuthMFAUnenrollResponse
AuthMFAVerifyResponse
AuthOptions
AuthResponse
Response which might or might not contain session and/or user
AuthSessionUrlResponse
AuthState
AuthUser
Binding
Bucket
BucketOptions
public The visibility of the bucket. Public buckets don't require an
authorization token to download objects, but still require a valid token for
all other operations. By default, buckets are private.
ByteStream
A stream of chunks of bytes representing a single piece of data.
CommitTableResult
The result of committing updates to a table.
CrashlyticsOptions
Configuration options for SupaCrashlyticsService .
CreateCustomProviderParams
Parameters for creating a new custom provider.
CreateOAuthClientParams
Parameters for creating a new OAuth client.
Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
CreateTableRequest
Request describing a table to create.
CustomOAuthProvider
Custom OAuth/OIDC provider object returned from the admin API.
DecodedJwt
Decoded JWT structure
DownloadBehavior
Controls download behavior for signed and public URLs.
EmptyLocalStorage
A LocalStorage implementation that does nothing. Use this to
disable persistence.
Factor
FileObject
FileObjectV2
FileOptions
FileSort
The column and direction that StorageFileApi.listPaginated sorts its
results by.
FunctionResponse
FunctionsClient
FunctionsClientOptions
GenerateLinkProperties
GenerateLinkResponse
GetClaimsOptions
Options for getClaims method
GetClaimsResponse
Response from getClaims method
GoTrueAdminApi
GoTrueAdminPasskeyApi
Admin methods for managing the passkeys of users.
GotrueAsyncStorage
Interface to provide async storage to store pkce tokens.
GoTrueClient
API client to interact with gotrue server.
GoTrueMFAApi
GoTrueOAuthApi
API namespace for the OAuth 2.1 authorization server consent flow.
GoTruePasskeyApi
API namespace for passkey (WebAuthn) authentication.
IcebergRestCatalog
Client for the Apache Iceberg REST Catalog exposed by Supabase Storage under
an analytics bucket. It manages namespaces and tables within a warehouse
(an analytics bucket).
IcebergType
A type in the Iceberg type system. Either a PrimitiveType represented by
a type string, or one of the nested types StructType , ListType and
MapType .
JWK
JSON Web Key (JWK) representation.
JWKSet
JWT Header structure
JwtPayload
JWT Payload structure with standard claims
JwtRawParts
Raw encoded parts of a JWT
ListBucketsOptions
Filter, sort and pagination options for StorageBucketApi.listBuckets.
ListNamespacesOptions
Options for listing namespaces.
ListNamespacesResult
The result of listing namespaces.
ListTablesOptions
Options for listing tables.
ListTablesResult
The result of listing tables in a namespace.
ListType
A list type whose elements are of type element .
LoadTableOptions
Options for loading a table.
LoadTableResult
The full result of loading, creating or registering a table, including the
server provided configuration, vended storage credentials and the response
ETag.
LocalStorage
LocalStorage is used to persist the user session in the device.
MapType
A map type with keys of type key and values of type value .
MultipartFile
A file to be uploaded as part of a MultipartRequest.
NotificationOptions
OAuthAuthorizationDetailsResponse
Response type representing the details of a pending OAuth authorization
request that still requires the user's consent.
OAuthAuthorizationRedirectResponse
Response type returned when the signed-in user has already granted consent
to the requesting client.
OAuthAuthorizationResponse
Result returned by GoTrueOAuthApi.getAuthorizationDetails .
OAuthAuthorizedClient
OAuth client object returned from the OAuth 2.1 server when the client is
authorized.
OAuthClient
OAuth client object returned from the OAuth 2.1 server.
Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
OAuthConsentResponse
Response type for an OAuth authorization consent decision (approve or deny).
OAuthGrant
An OAuth grant representing a user's authorization of an OAuth client.
OAuthProvider
An OAuth provider identifier.
OAuthResponse
Response of OAuth signin
OIDCDiscoveryDocument
OIDC discovery document fields.
PaginatedFile
A file entry returned by StorageFileApi.listPaginated .
PaginatedFolder
A folder entry returned by StorageFileApi.listPaginated when using a
delimiter.
PaginatedListResult
The result of StorageFileApi.listPaginated .
PaginatedSearchOptions
Options for StorageFileApi.listPaginated .
PartitionField
A single field of a PartitionSpec .
PartitionSpec
Describes how a table is partitioned.
Passkey
A passkey (WebAuthn credential) registered to a user.
PasskeyAuthenticationOptionsResponse
Response containing the options needed to sign in with a passkey.
PasskeyRegistrationOptionsResponse
Response containing the options needed to register a new passkey.
PhoneEnrollment
PostgresChangeFilter
Creates a filter for realtime postgres change listener.
PostgresChangePayload
Data class that contains the Postgres change event payload.
PostgresColumn
PostgrestBuilder <T , S , R >
The base builder class.
PostgrestClient
A PostgREST api client written in Dartlang. The goal of this library is to make an "ORM-like" restful interface.
PostgrestFilterBuilder <T >
PostgrestOptions
PostgrestQueryBuilder <T >
The query builder class provides a convenient interface to creating request queries.
PostgrestResponse <T >
A Postgrest response
PostgrestRpcBuilder
PostgrestTransformBuilder <T >
Presence
A single shared state between users with Realtime Presence.
PresenceEvents
PresenceOpts
PrimitiveType
A primitive Iceberg type such as int, string, decimal(10,2) or
fixed[16].
RawPostgrestBuilder <T , S , R >
Needed as a wrapper around PostgrestBuilder to allow for the different return type of withConverter than in ResponsePostgrestBuilder.withConverter .
RawTableUpdate
RealtimeChannel
RealtimeChannelConfig
RealtimeClient
Manages a persistent WebSocket connection to the Supabase Realtime server.
RealtimeCloseEvent
Event details for when the connection closed.
RealtimeOptions
RealtimePresence
RealtimePresenceJoinPayload
Payload for PresenceEvent.join callback.
RealtimePresenceLeavePayload
Payload for PresenceEvent.leave callback.
RealtimePresencePayload
Base class for the payload in .onPresence() callback functions.
RealtimePresenceSyncPayload
Payload for PresenceEvent.sync callback.
RealtimeSystemPayload
Payload of a system event emitted by the server.
RegisterTableRequest
Request to register an existing metadata file as a table.
RemoteConfigOption
RemovePartitionSpecsUpdate
RemovePropertiesUpdate
RemoveSchemasUpdate
RemoveSnapshotReferenceUpdate
RemoveSnapshotsUpdate
RemoveSubscriptionResult
ReplayOption
Configuration for broadcast replay feature.
Allows replaying broadcast messages from a specific timestamp.
ResendResponse
ResponsePostgrestBuilder <T , S , R >
Needed as a wrapper around PostgrestBuilder to allow for the different return type of withConverter than in RawPostgrestBuilder.withConverter .
RetryOption
SearchOptions
Session
SetCurrentSchemaUpdate
SetDefaultSortOrderUpdate
SetDefaultSpecUpdate
SetLocationUpdate
SetPropertiesUpdate
SetSnapshotReferenceUpdate
SharedPreferencesGotrueAsyncStorage
local storage to store pkce flow code verifier.
SharedPreferencesLocalStorage
A LocalStorage implementation that implements SharedPreferences as the
storage method.
SignedUploadURLResponse
SignedUrl
SignedUrlFailure
A failed SignedUrlResult : the path could not be signed (e.g. the file does not exist).
SignedUrlResult
Represents a per-item result from StorageFileApi.createSignedUrlsResult .
SignedUrlSuccess
A successful SignedUrlResult : the file was found and a signed URL was generated.
SinglePresenceState
A single client connected through presence.
Snapshot
A snapshot of a table at a point in time.
SnapshotReference
A reference (branch or tag) pointing at a snapshot.
SocialAuthResult
this is result model of login specialy for social media providers
this model is used to return id token and raw data from social media providers
SortBy
SortField
A single field of a SortOrder .
SortOrder
Describes how a table is sorted when written.
StorageCredential
Temporary storage credentials vended by the server for a table path prefix.
StorageFileApi
StorageOptions
StorageRetryController
StorageVectorBucketApi
Index operations scoped to a single vector bucket.
StorageVectorIndexApi
Vector data operations scoped to a single index within a bucket.
StructType
A nested struct type containing fields .
Supabase
Supabase instance.
SupabaseAuth
Handles all authentication operations with Supabase.
SupabaseClient
Creates a Supabase client to interact with your Supabase instance.
SupabaseQueryBuilder
SupabaseQuerySchema
Used to perform rpc and from operations with a different schema than in SupabaseClient .
SupabaseStorageClient
SupabaseStreamBuilder
SupabaseStreamFilterBuilder
SupabaseVectorsClient
Client for the Storage Vectors API, reachable through
supabase.storage.vectors.
SupaCrashlyticsService
SupaCrashlyticsService
SupaCrashReport
Represents a single crash report entry.
SupaDatabase
A unified interface for all Supabase database operations.
SupaHelper
SupaNotification
SupaNotificationService
SupaPage <T >
SupaRealTime
SupaRemoteConfig
SupaRemoteConfig
SupaSocialMediaAuth
to Add new Social Media Provider
implement SupaSocialMediaAuth
SupaStorage
TableField
A field within a StructType or a TableSchema .
TableIdentifier
Identifies a table by its namespace and name.
TableMetadata
Metadata describing the current state of a table, returned when loading or
committing to a table.
TableRequirement
A precondition that must hold for a table commit to be applied. The server
rejects the commit if any requirement is not met.
TableSchema
The schema of a table, a struct of fields .
TableUpdate
A single change applied to a table as part of a commit. The common data
definition updates are modelled as dedicated subclasses. Updates that are
not modelled (for example snapshot, statistics and encryption key updates)
can be sent with TableUpdate.raw .
TOTPEnrollment
TraceContext
W3C trace context headers.
TracePropagationOptions
Options controlling W3C trace context propagation onto outgoing Supabase
requests.
TransformOptions
Specifies the dimensions and the resize mode of the requesting image.
UpdateCustomProviderParams
Parameters for updating an existing custom provider.
UpdateNamespacePropertiesResult
The result of a namespace properties update.
UpdateOAuthClientParams
Parameters for updating an existing OAuth client.
Only relevant when the OAuth 2.1 server is enabled in Supabase Auth.
UpgradeFormatVersionUpdate
User
UserAttributes
UserIdentity
UserResponse
Response that contains a user
Vector
A single vector to insert or update through
StorageVectorIndexApi.putVectors .
VectorBucket
Metadata describing a vector bucket.
VectorBucketEncryption
Encryption settings attached to a vector bucket.
VectorBucketList
The result of SupabaseVectorsClient.listBuckets .
VectorIndex
Metadata describing a vector index within a bucket.
VectorIndexList
The result of StorageVectorBucketApi.listIndexes .
VectorList
The result of StorageVectorIndexApi.listVectors .
VectorMatch
A vector returned from a get, list or query operation.
VectorQueryResult
The result of StorageVectorIndexApi.queryVectors .
Functions
convertCell (String type , dynamic value )
→ dynamic
If the value of the cell is null, returns null.
Otherwise converts the string value to the correct type.
convertChangeData (List <Map <String , dynamic > > columns , Map <String , dynamic > record , {List <String > ? skipTypes })
→ Map <String , dynamic >
Takes an array of columns and an object of string values then converts each string value
to its mapped type.
convertColumn (String columnName , List <PostgresColumn > columns , Map <String , dynamic > record , List <String > skipTypes )
→ dynamic
Converts the value of an individual column.
decodeJwt (String token )
→ DecodedJwt
Decodes a JWT token without performing validation
httpEndpointURL (String socketUrl )
→ String
Converts a WebSocket URL to an HTTP URL.
noop (dynamic value )
→ dynamic
toArray (dynamic value , String type )
→ dynamic
Converts a Postgres Array into a native Dart array
toBoolean (dynamic value )
→ bool ?
toDouble (dynamic value )
→ double ?
toInt (dynamic value )
→ int ?
toJson (dynamic value )
→ dynamic
toTimestampString (String ? value )
→ String ?
Fixes timestamp to be ISO-8601. Swaps the space between the date and time for a 'T'
See https://github.com/supabase/supabase/issues/18
validateExp (int ? exp )
→ void
Validates the expiration time of a JWT
Typedefs
BindingCallback
= void Function(dynamic payload , [dynamic ref ])
BroadcastChannel
= ({void Function() close , Stream <Map <String , dynamic > > onMessage , void Function(Map ) postMessage } )
PostgrestConverter <S , T >
= S Function(T data )
PostgrestList
= List <PostgrestMap >
PostgrestListResponse
= PostgrestResponse <PostgrestList >
PostgrestMap
= Map <String , dynamic >
PostgrestMapResponse
= PostgrestResponse <PostgrestMap >
PresenceChooser <T >
= T Function(String key , dynamic presence )
PresenceOnJoinCallback
= void Function(String ? key , dynamic currentPresences , dynamic newPresences )
PresenceOnLeaveCallback
= void Function(String ? key , dynamic currentPresences , dynamic newPresences )
RealtimeConstants
= Constants
RealtimeDecode
= Map <String , dynamic > Function(Object payload )
Deserializes a raw incoming WebSocket frame (String or binary) into a
message map.
RealtimeEncode
= Object Function(Map <String , dynamic > payload )
Serializes an outgoing message into the String or binary frame written to
the WebSocket.
SupabaseStreamEvent
= List <Map <String , dynamic > >
TraceContextProvider
= FutureOr <TraceContext ? > Function()
Supplies the current W3C trace context for outgoing Supabase requests.
WebSocketTransport
= WebSocketChannel Function(String url , )