ListNamespacesResult class
The result of listing namespaces.
Constructors
-
ListNamespacesResult({required List<
List< namespaces, String? nextPageToken})String> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
namespaces
→ List<
List< String> > -
final
- nextPageToken → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited