ListTablesResult class

The result of listing tables in a namespace.

Constructors

ListTablesResult({required List<TableIdentifier> identifiers, String? nextPageToken})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
identifiers List<TableIdentifier>
final
nextPageToken String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited