PartitionField class

A single field of a PartitionSpec.

Constructors

PartitionField({required int sourceId, required String name, required String transform, int? fieldId})
const
PartitionField.fromJson(Map<String, dynamic> json)
factory

Properties

fieldId int?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceId int
final
transform String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited