SocketStates enum

Inheritance
Available extensions

Values

connecting → const SocketStates

Client attempting to establish a connection

open → const SocketStates

Connection is live and connected

disconnecting → const SocketStates

Socket is closing by the user

closed → const SocketStates

Socket being close not by the user. Realtime should attempt to reconnect.

disconnected → const SocketStates

Socket being closed by the user

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SocketStates>
A constant List of the values in this enum, in order of their declaration.