SupaRealtimeException class final

Thrown when a realtime subscription operation fails.

Inheritance

Constructors

SupaRealtimeException({required String message, Object? rawError, String? statusCode})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
rawError Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited