CrashlyticsOptions class final
Configuration options for SupaCrashlyticsService.
Constructors
- CrashlyticsOptions({required String tableName, String? appVersion, bool enableInDebug = false, bool debug = false})
-
const
Properties
- appVersion → String?
-
App version attached to every report (e.g.
'1.2.3').final - debug → bool
-
Whether to print service activity to the console.
final
- enableInDebug → bool
-
Whether to send crash reports in debug builds.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableName → String
-
Supabase table where crash reports are stored.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited