TableUpdate class sealed
A single change applied to a table as part of a commit. The common data definition updates are modelled as dedicated subclasses. Updates that are not modelled (for example snapshot, statistics and encryption key updates) can be sent with TableUpdate.raw.
Constructors
-
TableUpdate.raw(String action, Map<
String, dynamic> body) -
An update expressed as a raw JSON map, for actions without a dedicated
subclass. The
actionkey is added automatically.constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited